# Copyright 2023-SomItCoop SCCL(<https://gitlab.com/somitcoop>)
# License AGPL-3.0 or later (https://www.gnu.org/licenses/agpl.html).
{
    "name": "Add default templates to mail activities",
    "version": "16.0.1.0.1",
    "depends": ["mail_activity_board"],
    "author": """
        Som It Cooperatiu SCCL,
        Som Connexió SCCL,
        Odoo Community Association (OCA)",
    """,
    "category": "Customer Relationship Management",
    "website": "https://gitlab.com/somitcoop/erp-research/odoo-helpdesk",
    "license": "AGPL-3",
    "summary": """
        Applies a mail template to the note field based on the mail activity type.
    """,
    "demo": [
        "demo/mail_template.xml",
        "demo/mail_activity_type.xml",
    ],
    "data": [
        "views/mail_activity_view.xml",
    ],
    "application": False,
    "installable": True,
}



from odoo import api, models


class MailActivity(models.Model):
    _inherit = "mail.activity"

    @api.onchange("activity_type_id")
    def _onchange_activity_type_id(self):
        if self.activity_type_id and len(self.activity_type_id.mail_template_ids) == 1:
            template = self.activity_type_id.mail_template_ids[0]
            self.note = template.body_html



from odoo.tests.common import TransactionCase


class TestMailActivity(TransactionCase):
    def test_onchange_activity_type_id(self):
        """Test that the note field is updated
        based on the activity type's mail template"""

        mail_activity_type_call = self.env.ref("mail.mail_activity_data_call")
        mail_activity_type_meeting = self.env.ref("mail.mail_activity_data_meeting")

        partner = self.env["res.partner"].create({"name": "Test Partner"})
        mail_activity = self.env["mail.activity"].create(
            {
                "activity_type_id": mail_activity_type_call.id,
                "res_id": partner.id,
                "res_model_id": self.env.ref("base.model_res_partner").id,
            }
        )

        mail_activity._onchange_activity_type_id()

        assert mail_activity.note in mail_activity_type_call.mail_template_ids.body_html

        mail_activity.activity_type_id = mail_activity_type_meeting
        mail_activity._onchange_activity_type_id()

        assert (
            mail_activity.note in mail_activity_type_meeting.mail_template_ids.body_html
        )
